# Vizro Vizro is a toolkit for creating modular data visualization applications.

##### Get Started

New to Vizro? Take a look at our tutorials to get started and to explore our core features.

##### User Guides

Our user guides provide step-by-step instructions on how to leverage our core features.

##### API reference

The API reference contains a detailed description of the Vizro API and our pydantic models.

##### Explanation

Our explanation section contains background information and the answer to "why" questions.

##### Contribute

Find our contribution guidelines and all our current and previous contributors here.